@@ -1,7 +1,7 @@
 package Test::Script;
 
 # ABSTRACT: Basic cross-platform tests for scripts
-our $VERSION = '1.11_02'; # TRIAL VERSION
+our $VERSION = '1.11_03'; # TRIAL VERSION
 
 
 use 5.006;
@@ -125,14 +125,16 @@ sub _preload_module
   # this is hopefully a pm file that nobody would use
   my $filename = File::Spec->catfile($dir, '__TEST_SCRIPT__.pm');
   my $fh;
-  open($fh, ">$filename");
-  print $fh 'unshift @INC, ',
+  open($fh, ">$filename") 
+    || die "unable to open $filename: $!";
+  print($fh 'unshift @INC, ',
     join ',', 
     # quotemeta is overkill, but it will make sure that characters
     # like " are quoted
     map { '"' . quotemeta . '"' }
-    grep { ! ref } @INC;
-  close $fh;
+    grep { ! ref } @INC)
+      || die "unable to write $filename: $!";
+  close($fh) || die "unable to close $filename: $!";;
   $dir;
 }
 
@@ -313,7 +315,7 @@ Test::Script - Basic cross-platform tests for scripts
 
 =head1 VERSION
 
-version 1.11_02
+version 1.11_03
 
 =head1 SYNOPSIS
 
